@@ -63,8 +63,7 @@ typedef enum {
 	EEL_BACKGROUND_TILED = 0, /* zero makes this the default placement */
 	EEL_BACKGROUND_CENTERED,
 	EEL_BACKGROUND_SCALED,
-	EEL_BACKGROUND_SCALED_ASPECT,
-	EEL_BACKGROUND_ZOOM
+	EEL_BACKGROUND_SCALED_ASPECT
 } EelBackgroundImagePlacement;
 
 GtkType                     eel_background_get_type                         (void);
@@ -189,12 +188,6 @@ gboolean                    eel_widget_has_attached_background              (Gtk
 /* Find the background ancestor for the widget. */
 GtkWidget *                 eel_gtk_widget_find_background_ancestor         (GtkWidget                   *widget);
 
-/* Should be TRUE for desktop background */
-void			    eel_background_set_desktop 			    (EelBackground              *background,
-									     GtkWidget *widget, 
-									     gboolean is_desktop);
-gboolean		    eel_background_is_desktop 			    (EelBackground              *background);
-
 typedef struct EelBackgroundDetails EelBackgroundDetails;
 
 struct EelBackground
