@@ -54,6 +54,8 @@ real_finalize (GObject *object)
 
 	g_free (label->details->full_text);
 	g_free (label->details);
+
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 GtkWidget*
@@ -61,7 +63,7 @@ eel_ellipsizing_label_new (const char *string)
 {
 	EelEllipsizingLabel *label;
   
-	label = gtk_type_new (EEL_TYPE_ELLIPSIZING_LABEL);
+	label = g_object_new (EEL_TYPE_ELLIPSIZING_LABEL, NULL);
 	eel_ellipsizing_label_set_text (label, string);
   
 	return GTK_WIDGET (label);
